local L = LibStub("AceLocale-3.0"):GetLocale("QuestItem")
local media = LibStub:GetLibrary("LibSharedMedia-3.0");

QuestItem.fonteffects = {
	["none"] = L["none"],
	["OUTLINE"] = L["OUTLINE"],
	["THICKOUTLINE"] = L["THICKOUTLINE"],
	["MONOCHROME"] = L["MONOCHROME"],
}

function QuestItem:GetOptions()
	local options = { 
		name = "QuestItem",
		handler = QuestItem,
		type='group',
		childGroups ='tree',
		args = {
			debug = {
				type = 'toggle',
				name = L["Debug mode"],
				desc = L["help_debug"],
				get = "debugQuery",
				set = "ActivateDebug",
				order = 9,
			},
			movebag = {
				type = 'toggle',
				name = L["Move Bag"],
				desc = L["help_movebag"],
				get = "BarShowQuery",
				set = "ShowHideBars",
				order = 10,
			},
			config = {
				type = 'execute',
				name = L["Configure Options"],
				desc = L["help_config"],
				func = "OpenConfig",
				order = 13,
			},
			version = {
				type = 'execute',
				name = L["Version"],
				desc = L["help_version"],
				func = "DisplayVersion",
				order = 15,
			},
			open = {
				type = 'execute',
				name = L["Open Quest Bag"],
				desc = L["help_open"],
				func = "DisplayQuestBag",
				guiHidden = true,
				order = 16,
			},
			show = {
				type = 'execute',
				name = L["Open Quest Bag"],
				desc = L["help_open"],
				func = "DisplayQuestBag",
				guiHidden = true,
				order = 17,
			},
			help = {
				type = 'description',
				name = L["help"],
				guiHidden = true,
				order = 18,
			},
		},
	}
	return options
end

function QuestItem:ActivateDebug()
	self.db.char.debug = not self.db.char.debug
	if (self.db.char.debug) then
		self:Print(L["config_debug_on"])
	else
		self:Print(L["config_debug_off"])
	end
end

function QuestItem:debugQuery()
	return self.db.char.debug
end

function QuestItem:FinishedMoving(var, frame)
	local point, relativeTo, relativePoint, xOffset, yOffset = frame:GetPoint();
	var.point = point
	var.relativeTo = relativeTo
	var.relativePoint = relativePoint
	var.xOffset = xOffset
	var.yOffset = yOffset
end

function QuestItem:GetWidth()
    return self.db.char.fWidth
end

function QuestItem:GetScale()
    return self.db.char.scale
end

function QuestItem:SetScale(info,newValue)
	self.db.char.scale = newValue
	self.BagFrame:SetScale(self.db.char.scale)
	self:Print("Scale set to : "..self.db.char.scale)
end

function QuestItem:OpenConfig()
	  if InterfaceOptionsFrame_OpenToCategory then
	    InterfaceOptionsFrame_OpenToCategory("QuestItem");
    else
        InterfaceOptionsFrame_OpenToFrame("QuestItem");
    end
end
